/*******************************************************************

This code includes the construction of the variables and indicators used
in Elias, Lacetera and Macis (AER P&P, 2015), as well as the estimations
described in the paper regarding the support for organ payments.

Further analyses and details can be found in Elias et al. (NBER Working Paper, 2015).

*******************************************************************/


clear
set more off

//THE DATASET TO USE FOR WHAT FOLLOWS IS aerpp-dataset1.dta 

//SOME BASIC DESCRIPTIVES AND RANDOMIZATION CHECKS

sum

table sgroups, c(mean y mean age mean male mean children mean altruist)

foreach v in wave y race relationship education employment income religion ideology {
tab `v' sgroups, col
}


//generate variables for analysis

tab sgroups, gen(sgroupsd)
tab groups, gen(groupsd)

gen age2=age^2
gen college=(education>=5)
tab ideology, gen (ideol_d)
//IN MOST ANALYSES, THE RESIDUAL CATEGORY 4 IS EXCLUDED BECAUSE IT IS SMALL AND TOO HETEROGENEOUS

tab income, gen (income_d)
tab religion, gen (relig_d)
tab education, gen (educ_d)
tab race, gen (ethn_d)
tab relationship, gen (rel_d)
tab children, gen (kid_d)
tab employment, gen (empl_d)

gen atheist=.
replace atheist=1 if religion==1
replace atheist=0 if religion>1&religion<=5

gen highearn=.
replace highearn=1 if income==4|income==5
replace highearn=0 if income==1|income==2|income==3


//INTERACTIONS OF TREATMENTS AND VARIABLES USED IN HETEROGENOUS EFFECTS ANALYSES

forvalues i=1(1)4   {
gen male_`i' = male*sgroupsd`i'
}

forvalues i=1(1)4   {
gen college_`i' = college*sgroupsd`i'
}

forvalues i=1(1)4   {
gen atheist_`i' = atheist*sgroupsd`i'
}

forvalues i=1(1)4   {
gen highearn_`i' = highearn*sgroupsd`i'
}

forvalues j=2(1)4  {
	forvalues i=1(1)4   {
gen ideol_`i'_`j' = ideol_d`j'*sgroupsd`i'
   }
}


//GENERATE A GLOBAL "CONTROL VARIABLE" FOR THE REGRESSIONS WITH CONTROLS BELOW
global controls male age age2 ethn_d2-ethn_d5 educ_d2-educ_d6 rel_d2-rel_d5 children empl_d2-empl_d7/*
*/ income_d2-income_d5 relig_d2-relig_d5 ideol_d2-ideol_d4 altruist i.state i.wave

sum male age age2 ethn_d2-ethn_d5 educ_d2-educ_d6 rel_d2-rel_d5 children empl_d2-empl_d7 income_d2-income_d5 relig_d2-relig_d5 ideol_d2-ideol_d4 altruist




//ANALYSES


//relabilility
table sgroups, c(mean reliable n reliable)
table groups, c(mean reliable n reliable)


//regression for  reliability answer (limited to conditions with a text)
reg reliable sgroupsd3-sgroupsd4 
reg reliable groupsd4-groupsd8



//SUPPORT RATES PER GROUP

mean y, over (sgroups)

//regression analyses

reg y sgroupsd2-sgroupsd4 , rob

//est. share for org.mkt with no txt is coefficient on sgroupd2:

//est. share for org.mkt (org text)
lincom (sgroupsd4-sgroupsd3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4-sgroupsd3)-(sgroupsd2)



//WITH CONTROL VARIABLES

reg y sgroupsd2-sgroupsd4 $controls , rob

//est. share for org.mkt with no txt is coefficient on sgroupd2:

//est. share for org.mkt (org text)
lincom (sgroupsd4-sgroupsd3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4-sgroupsd3)-(sgroupsd2)



//HETEROGENEOUS EFFECTS: GENDER, RELIGION, EDUCATION, POLITICAL VIES, INCOME


// GENDER

mean y, over (male sgroups)

reg y sgroupsd2-sgroupsd4 male_1-male_4 , rob

//WOMEN

//est. share for org.mkt with no txt is coefficient on sgroupd2:

//est. share for org.mkt (org text)
lincom (sgroupsd4-sgroupsd3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4-sgroupsd3)-(sgroupsd2)


//MEN:  

//est. share for org.mkt with no txt
lincom (sgroupsd2+male_2)-male_1

//est. share for org.mkt (org text)
lincom (sgroupsd4+male_4-sgroupsd3-male_3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4+male_4-sgroupsd3-male_3)-((sgroupsd2+male_2)-male_1)


//MEN VS WOMEN
//est. share for org.mkt with no txt:
lincom (male_2)-male_1

//est. share for org.mkt (org text)
lincom (male_4-male_3)

//diff between the two
lincom ((male_4-male_3))-((male_2)-male_1)


//WITH CONTROL VARIABLES

reg y sgroupsd2-sgroupsd4 male_1-male_4 $controls  , rob
*outreg2 using wave12-aggr-splits.xls, slow(4000)  append

//WOMEN:  

//est. share for org.mkt with no txt is coefficient on sgroupd2:

//est. share for org.mkt (org text)
lincom (sgroupsd4-sgroupsd3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4-sgroupsd3)-(sgroupsd2)


//MEN:  

//est. share for org.mkt with no txt
lincom (sgroupsd2+male_2)-male_1

//est. share for org.mkt (org text)
lincom (sgroupsd4+male_4-sgroupsd3-male_3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4+male_4-sgroupsd3-male_3)-((sgroupsd2+male_2)-male_1)


//MEN VS WOMEN
//est. share for org.mkt with no txt:
lincom (male_2)-male_1

//est. share for org.mkt (org text)
lincom (male_4-male_3)

//diff between the two
lincom ((male_4-male_3))-((male_2)-male_1)



//EDUCATION (<COLLEGE VS. COLLEGE+)

mean y, over (college sgroups)

reg y sgroupsd2-sgroupsd4 college_1-college_4 , rob

// <COLLEGE
//est. share for org.mkt with no txt is coefficient on sgroupd2:

//est. share for org.mkt (org text)
lincom (sgroupsd4-sgroupsd3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4-sgroupsd3)-(sgroupsd2)


//COLLEGE+

//est. share for org.mkt with no txt
lincom (sgroupsd2+college_2)-college_1

//est. share for org.mkt (org text)
lincom (sgroupsd4+college_4-sgroupsd3-college_3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4+college_4-sgroupsd3-college_3)-((sgroupsd2+college_2)-college_1)


//COLLEGE+ VS <COLLEGE
//est. share for org.mkt with no txt:
lincom (college_2)-college_1

//est. share for org.mkt (org text)
lincom (college_4-college_3)

//diff between the two
lincom (college_4-college_3)-((college_2)-college_1)


//WITH CONTROL VARIABLES

reg y sgroupsd2-sgroupsd4 college_1-college_4 $controls , rob

//<COLLEGE
//est. share for org.mkt with no txt is coefficient on sgroupd2:

//est. share for org.mkt (org text)
lincom (sgroupsd4-sgroupsd3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4-sgroupsd3)-(sgroupsd2)


//COLLEGE+

//est. share for org.mkt with no txt
lincom (sgroupsd2+college_2)-college_1

//est. share for org.mkt (org text)
lincom (sgroupsd4+college_4-sgroupsd3-college_3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4+college_4-sgroupsd3-college_3)-((sgroupsd2+college_2)-college_1)


//COLLEGE+ VS <COLLEGE
//est. share for org.mkt with no txt:
lincom (college_2)-college_1

//est. share for org.mkt (org text)
lincom (college_4-college_3)

//diff between the two
lincom (college_4-college_3)-((college_2)-college_1)




//RELIGIOSITY

mean y, over (atheist sgroups)



reg y sgroupsd2-sgroupsd4 atheist_1-atheist_4 , rob

//RELIGIOUS
//est. share for org.mkt with no txt is coefficient on sgroupd2:

//est. share for org.mkt (org text)
lincom (sgroupsd4-sgroupsd3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4-sgroupsd3)-(sgroupsd2)


//NON-RELIGIOUS

//est. share for org.mkt with no txt
lincom (sgroupsd2+atheist_2)-atheist_1

//est. share for org.mkt (org text)
lincom (sgroupsd4+atheist_4-sgroupsd3-atheist_3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4+atheist_4-sgroupsd3-atheist_3)-((sgroupsd2+atheist_2)-atheist_1)


//NON-RELIGIOUS VS RELIGIOUS
//est. share for org.mkt with no txt:
lincom (atheist_2)-atheist_1

//est. share for org.mkt (org text)
lincom (atheist_4-atheist_3)

//diff between the two
lincom (atheist_4-atheist_3)-((atheist_2)-atheist_1)


//WITH CONTROL VARIABLES

reg y sgroupsd2-sgroupsd4 atheist_1-atheist_4 $controls , rob

//RELIGIOUS

//est. share for org.mkt with no txt is coefficient on sgroupd2:

//est. share for org.mkt (org text)
lincom (sgroupsd4-sgroupsd3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4-sgroupsd3)-(sgroupsd2)


//NON-RELIGIOUS

//est. share for org.mkt with no txt
lincom (sgroupsd2+atheist_2)-atheist_1

//est. share for org.mkt (org text)
lincom (sgroupsd4+atheist_4-sgroupsd3-atheist_3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4+atheist_4-sgroupsd3-atheist_3)-((sgroupsd2+atheist_2)-atheist_1)


//NON-RELIGIOUS VS RELIGIOUS

//est. share for org.mkt with no txt:
lincom (atheist_2)-atheist_1

//est. share for org.mkt (org text)
lincom (atheist_4-atheist_3)

//diff between the two
lincom (atheist_4-atheist_3)-((atheist_2)-atheist_1)


//POLITICAL VIEWS

mean y, over (ideology sgroups)

reg y sgroupsd2-sgroupsd4 ideol_1_2- ideol_4_3  if ideology>=1&ideology<=3

//CONSERVATIVES

//est. share for org.mkt with no txt is coefficient on sgroupsd2

//est. share for org.mkt (org text)
lincom (sgroupsd4-sgroupsd3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4-sgroupsd3)-(sgroupsd2)


//LIBERALS

//est. share for org.mkt with no txt
lincom (sgroupsd2+ideol_2_2)-ideol_1_2

//est. share for org.mkt (org text)
lincom (sgroupsd4+ideol_4_2-sgroupsd3-ideol_3_2)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4+ideol_4_2-sgroupsd3-ideol_3_2)-((sgroupsd2+ideol_2_2)-ideol_1_2)


//MODERATES

//est. share for org.mkt with no txt
lincom (sgroupsd2+ideol_2_3)-ideol_1_3

//est. share for org.mkt (org text)
lincom (sgroupsd4+ideol_4_3-sgroupsd3-ideol_3_3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4+ideol_4_3-sgroupsd3-ideol_3_3)-(sgroupsd2+ideol_2_3-ideol_1_3)



//LIBERALS - CONSERVATIVES
//est. share for org.mkt with no txt:
lincom ideol_2_2-ideol_1_2

//est. share for org.mkt (org text)
lincom ideol_4_2-ideol_3_2

//diff between the two
lincom (ideol_4_2-ideol_3_2)-(ideol_2_2-ideol_1_2)


//LIBERALS - MODERATES
//est. share for org.mkt with no txt:
lincom (ideol_2_2-ideol_1_2)-(ideol_2_3-ideol_1_3)

//est. share for org.mkt (org text)
lincom (ideol_4_2-ideol_3_2)-(ideol_4_3-ideol_3_3)

//diff between the two
lincom ((ideol_4_2-ideol_3_2)-(ideol_4_3-ideol_3_3))-((ideol_2_2-ideol_1_2)-(ideol_2_3-ideol_1_3))


//MODERATES - CONSERVATIVES
//est. share for org.mkt with no txt:
lincom ideol_2_3-ideol_1_3

//est. share for org.mkt (org text)
lincom ideol_4_3-ideol_3_3

//diff between the two
lincom (ideol_4_3-ideol_3_3)-(ideol_2_3-ideol_1_3)



//WITH CONTROL VARIABLES

reg y sgroupsd2-sgroupsd4 ideol_1_2- ideol_4_3 $controls  if ideology>=1&ideology<=3

//CONSERVATIVES

//est. share for org.mkt with no txt is coefficient on sgroupsd2

//est. share for org.mkt (org text)
lincom (sgroupsd4-sgroupsd3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4-sgroupsd3)-(sgroupsd2)


//LIBERALS

//est. share for org.mkt with no txt
lincom (sgroupsd2+ideol_2_2)-ideol_1_2

//est. share for org.mkt (org text)
lincom (sgroupsd4+ideol_4_2-sgroupsd3-ideol_3_2)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4+ideol_4_2-sgroupsd3-ideol_3_2)-((sgroupsd2+ideol_2_2)-ideol_1_2)


//MODERATES

//est. share for org.mkt with no txt
lincom (sgroupsd2+ideol_2_3)-ideol_1_3

//est. share for org.mkt (org text)
lincom (sgroupsd4+ideol_4_3-sgroupsd3-ideol_3_3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4+ideol_4_3-sgroupsd3-ideol_3_3)-(sgroupsd2+ideol_2_3-ideol_1_3)



//LIBERALS - CONSERVATIVES
//est. share for org.mkt with no txt:
lincom ideol_2_2-ideol_1_2

//est. share for org.mkt (org text)
lincom ideol_4_2-ideol_3_2

//diff between the two
lincom (ideol_4_2-ideol_3_2)-(ideol_2_2-ideol_1_2)


//LIBERALS - MODERATES
//est. share for org.mkt with no txt:
lincom (ideol_2_2-ideol_1_2)-(ideol_2_3-ideol_1_3)

//est. share for org.mkt (org text)
lincom (ideol_4_2-ideol_3_2)-(ideol_4_3-ideol_3_3)

//diff between the two
lincom ((ideol_4_2-ideol_3_2)-(ideol_4_3-ideol_3_3))-((ideol_2_2-ideol_1_2)-(ideol_2_3-ideol_1_3))


//MODERATES - CONSERVATIVES
//est. share for org.mkt with no txt:
lincom ideol_2_3-ideol_1_3

//est. share for org.mkt (org text)
lincom ideol_4_3-ideol_3_3

//diff between the two
lincom (ideol_4_3-ideol_3_3)-(ideol_2_3-ideol_1_3)





//INCOME

mean y, over (highearn sgroups)

reg y sgroupsd2-sgroupsd4 highearn_1-highearn_4 , rob

//LOW INCOME

//est. share for org.mkt with no txt is coefficient on sgroupd2

//est. share for org.mkt (org text)
lincom (sgroupsd4-sgroupsd3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4-sgroupsd3)-(sgroupsd2)


//HIGH INCOME

//est. share for org.mkt with no txt
lincom (sgroupsd2+highearn_2)-highearn_1

//est. share for org.mkt (org text)
lincom (sgroupsd4+highearn_4-sgroupsd3-highearn_3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4+highearn_4-sgroupsd3-highearn_3)-((sgroupsd2+highearn_2)-highearn_1)


//HIGH INCOME VS LOW INCOME
//est. share for org.mkt with no txt:
lincom (highearn_2)-highearn_1

//est. share for org.mkt (org text)
lincom (highearn_4-highearn_3)

//diff between the two
lincom (highearn_4-highearn_3)-((highearn_2)-highearn_1)

 
//WITH CONTROL VARIABLES

reg y sgroupsd2-sgroupsd4 highearn_1-highearn_4 $controls , rob


//LOW INCOME

//est. share for org.mkt with no txt is coefficient on sgroupd2

//est. share for org.mkt (org text)
lincom (sgroupsd4-sgroupsd3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4-sgroupsd3)-(sgroupsd2)


//HIGH INCOME

//est. share for org.mkt with no txt
lincom (sgroupsd2+highearn_2)-highearn_1

//est. share for org.mkt (org text)
lincom (sgroupsd4+highearn_4-sgroupsd3-highearn_3)

// est. diff in favor of org. mkt between org text and no text
lincom (sgroupsd4+highearn_4-sgroupsd3-highearn_3)-((sgroupsd2+highearn_2)-highearn_1)


//HIGH INCOME VS LOW INCOME
//est. share for org.mkt with no txt:
lincom (highearn_2)-highearn_1

//est. share for org.mkt (org text)
lincom (highearn_4-highearn_3)

//diff between the two
lincom (highearn_4-highearn_3)-((highearn_2)-highearn_1)



***************************************************
//THE ANALYSIS BELOW DISAGGREGATES TREATMENT CONDITIONS FURTHER: PLACEBO TEXT SEPARATED FORM CONTROL, 
//AND TREATMENT CONDITIONS SEPARATED BY TYPE OF COMPREHENSION QUESTION (RELATED OR NOT TO THE PRIOCE MECHANISMS)
//THE ANALYSIS IS ALSO SEPARATED BY WAVES 
//(BECAUSE THE PLACEBO TEXT AND THE DIFFERENT COMPREHENSION QUESTIONS WERE ONLY IMPLEMENTED IN MAY 2014 (WAVE1)


//FULL SAMPLE

mean y, over(groups)
 
tab groups


reg y groupsd2-groupsd8, rob


//est. share for org.mkt with no txt is coefficient on groupd2:

//est. share for org.mkt -- flu text
lincom (groupsd4-groupsd3)

//est. share for org.mkt -- org text, no price question
lincom (groupsd6-groupsd5)

//est. share for org.mkt -- org text, price question
lincom (groupsd8-groupsd7)

// est. diff in favor of org. mkt between flu text and no text
lincom (groupsd4-groupsd3)-(groupsd2)

// est. diff in favor of org. mkt between org. text (no price question) and no text 
lincom (groupsd6-groupsd5)-(groupsd2)

// est. diff in favor of org. mkt between org. text (no price question) and flu text 
lincom (groupsd6-groupsd5)-(groupsd4-groupsd3)

// est. diff in favor of org. mkt between org. text (price question) and no text 
lincom (groupsd8-groupsd7)-(groupsd2)

// est. diff in favor of org. mkt between org. text (price question) and flu text 
lincom (groupsd8-groupsd7)-(groupsd4-groupsd3)

// est. diff in favor of org. mkt between org. text (price question) and org. text (no price question) 
lincom (groupsd8-groupsd7)-(groupsd6-groupsd5)



//ONLY WAVE 1


mean y if wave==1, over(groups)

tab groups if wave==1

reg y groupsd2-groupsd8 if wave==1, rob

// 

//est. share for org.mkt with no txt is coefficient on groupd2:

//est. share for org.mkt -- flu text
lincom (groupsd4-groupsd3)

//est. share for org.mkt -- org text, no price question
lincom (groupsd6-groupsd5)

//est. share for org.mkt -- org text, price question
lincom (groupsd8-groupsd7)

// est. diff in favor of org. mkt between flu text and no text
lincom (groupsd4-groupsd3)-(groupsd2)

// est. diff in favor of org. mkt between org. text (no price question) and no text 
lincom (groupsd6-groupsd5)-(groupsd2)

// est. diff in favor of org. mkt between org. text (no price question) and flu text 
lincom (groupsd6-groupsd5)-(groupsd4-groupsd3)

// est. diff in favor of org. mkt between org. text (price question) and no text 
lincom (groupsd8-groupsd7)-(groupsd2)

// est. diff in favor of org. mkt between org. text (price question) and flu text 
lincom (groupsd8-groupsd7)-(groupsd4-groupsd3)

// est. diff in favor of org. mkt between org. text (price question) and org. text (no price question) 
lincom (groupsd8-groupsd7)-(groupsd6-groupsd5)





//WITH CONTROL VARIABLES

reg y groupsd2-groupsd8 $controls, rob


//est. share for org.mkt with no txt is coefficient on groupd2:

//est. share for org.mkt -- flu text
lincom (groupsd4-groupsd3)

//est. share for org.mkt -- org text, no price question
lincom (groupsd6-groupsd5)

//est. share for org.mkt -- org text, price question
lincom (groupsd8-groupsd7)

// est. diff in favor of org. mkt between flu text and no text
lincom (groupsd4-groupsd3)-(groupsd2)

// est. diff in favor of org. mkt between org. text (no price question) and no text 
lincom (groupsd6-groupsd5)-(groupsd2)

// est. diff in favor of org. mkt between org. text (no price question) and flu text 
lincom (groupsd6-groupsd5)-(groupsd4-groupsd3)

// est. diff in favor of org. mkt between org. text (price question) and no text 
lincom (groupsd8-groupsd7)-(groupsd2)

// est. diff in favor of org. mkt between org. text (price question) and flu text 
lincom (groupsd8-groupsd7)-(groupsd4-groupsd3)

// est. diff in favor of org. mkt between org. text (price question) and org. text (no price question) 
lincom (groupsd8-groupsd7)-(groupsd6-groupsd5)


//ONLY WAVE 1



//main regression
mean y if wave==1, over(groups)

tab groups

reg y groupsd2-groupsd8 $controls if wave==1, rob
*outreg2 using wave12_disaggr.xls, slow(4000)   append 

// 

//est. share for org.mkt with no txt is coefficient on groupd2:

//est. share for org.mkt -- flu text
lincom (groupsd4-groupsd3)

//est. share for org.mkt -- org text, no price question
lincom (groupsd6-groupsd5)

//est. share for org.mkt -- org text, price question
lincom (groupsd8-groupsd7)

// est. diff in favor of org. mkt between flu text and no text
lincom (groupsd4-groupsd3)-(groupsd2)

// est. diff in favor of org. mkt between org. text (no price question) and no text 
lincom (groupsd6-groupsd5)-(groupsd2)

// est. diff in favor of org. mkt between org. text (no price question) and flu text 
lincom (groupsd6-groupsd5)-(groupsd4-groupsd3)

// est. diff in favor of org. mkt between org. text (price question) and no text 
lincom (groupsd8-groupsd7)-(groupsd2)

// est. diff in favor of org. mkt between org. text (price question) and flu text 
lincom (groupsd8-groupsd7)-(groupsd4-groupsd3)

// est. diff in favor of org. mkt between org. text (price question) and org. text (no price question) 
lincom (groupsd8-groupsd7)-(groupsd6-groupsd5)






